Command

Enum Command 

pub(crate) enum Command {
    Transaction,
    Cat {
        name: String,
    },
    GC {
        root: Vec<String>,
        dry_run: bool,
    },
    ImportImage {
        reference: String,
    },
    Oci {
        cmd: OciCommand,
    },
    Mount {
        name: String,
        mountpoint: String,
    },
    CreateImage {
        fs_opts: FsReadOptions,
        image_name: Option<String>,
    },
    ComputeId {
        fs_opts: FsReadOptions,
    },
    CreateDumpfile {
        fs_opts: FsReadOptions,
    },
    ImageObjects {
        name: String,
    },
}

Variants



Transaction

Take a transaction lock on the repository. This prevents garbage collection from occurring.



Cat

Reconstitutes a split stream and writes it to stdout

Fields

name: String

the name of the stream to cat, either a content identifier or prefixed with ‘ref/’



GC

Perform garbage collection

Fields

root: Vec<String>

Additional roots to keep (image or stream names)

dry_run: bool

Preview what would be deleted without actually deleting



ImportImage

Imports a composefs image (unsafe!)

Fields

reference: String


Oci

Commands for dealing with OCI images and layers

Fields



Mount

Mounts a composefs image, possibly enforcing fsverity of the image

Fields

name: String

the name of the image to mount, either an fs-verity hash or prefixed with ‘ref/’

mountpoint: String

the mountpoint



CreateImage

Read rootfs located at a path, add all files to the repo, then create the composefs image of the rootfs, commit it to the repo, and print its image object ID

Fields

image_name: Option<String>

optional reference name for the image, use as ‘ref/’ elsewhere



ComputeId

Read rootfs located at a path, add all files to the repo, then compute the composefs image object id of the rootfs. Note that this does not create or commit the composefs image itself.

Fields



CreateDumpfile

Read rootfs located at a path, add all files to the repo, then dump full content of the rootfs to a composefs dumpfile and write to stdout.

Fields



ImageObjects

Lists all object IDs referenced by an image

Fields

name: String

the name of the image to read, either an object ID digest or prefixed with ‘ref/’