OciCommand

Enum OciCommand 

pub(crate) enum OciCommand {
Show 14 variants ImportLayer { digest: String, name: Option<String>, }, LsLayer { name: String, }, Dump { config_opts: OCIConfigFilesystemOptions, }, Pull { image: String, name: Option<String>, }, ListImages { json: bool, }, Inspect { image: String, manifest: bool, config: bool, }, Tag { manifest_digest: String, name: String, }, Untag { name: String, }, LayerInspect { layer: String, dumpfile: bool, json: bool, }, ComputeId { config_opts: OCIConfigFilesystemOptions, }, CreateImage { config_opts: OCIConfigFilesystemOptions, image_name: Option<String>, }, Seal { config_opts: OCIConfigOptions, }, Mount { name: String, mountpoint: String, }, PrepareBoot { config_opts: OCIConfigOptions, bootdir: PathBuf, entry_id: Option<String>, cmdline: Vec<String>, },
}

Variants



ImportLayer

Stores a tar layer file as a splitstream in the repository.

Fields

digest: String


LsLayer

Lists the contents of a tar stream

Fields

name: String

the name of the stream to list, either a stream ID in format oci-config-<hash_type>:<hash_digest> or a reference in ‘ref/’



Dump

Dump full content of the rootfs of a stored OCI image to a composefs dumpfile and write to stdout

Fields



Pull

Pull an OCI image to be stored in repo then prints the stream and verity digest of its manifest

Fields

image: String

source image reference, as accepted by skopeo

name: Option<String>

optional reference name for the manifest, use as ‘ref/’ elsewhere



ListImages

List all tagged OCI images in the repository

Fields

json: bool

Output as JSON array



Inspect

Show information about an OCI image

By default, outputs JSON with manifest, config, and referrers. Use –manifest or –config to output just that raw JSON.

Fields

image: String

Image reference (tag name or manifest digest)

manifest: bool

Output only the raw manifest JSON (as originally stored)

config: bool

Output only the raw config JSON (as originally stored)



Tag

Tag an image with a new name

Fields

manifest_digest: String

Manifest digest (sha256:…)

name: String

Tag name to assign



Untag

Remove a tag from an image

Fields

name: String

Tag name to remove



LayerInspect

Inspect a stored layer

By default, outputs the raw tar stream to stdout. Use –dumpfile for composefs dumpfile format, or –json for metadata.

Fields

layer: String

Layer diff_id (sha256:…)

dumpfile: bool

Output as composefs dumpfile format (one entry per line)

json: bool

Output layer metadata as JSON



ComputeId

Compute the composefs image object id of the rootfs of a stored OCI image

Fields



CreateImage

Create the composefs image of the rootfs of a stored OCI image, commit it to the repo, and print its image object ID

Fields

image_name: Option<String>

optional reference name for the image, use as ‘ref/’ elsewhere



Seal

Seal a stored OCI image by creating a cloned manifest with embedded verity digest (a.k.a. composefs image object ID) in the repo, then prints the stream and verity digest of the new sealed manifest

Fields

config_opts: OCIConfigOptions


Mount

Mounts a stored and sealed OCI image by looking up its composefs image. Note that the composefs image must be built and committed to the repo first

Fields

name: String

the name of the target OCI manifest stream, either a stream ID in format oci-config-<hash_type>:<hash_digest> or a reference in ‘ref/’

mountpoint: String

the mountpoint



PrepareBoot

Create the composefs image of the rootfs of a stored OCI image, perform bootable transformation, commit it to the repo, then configure boot for the image by writing new boot resources and bootloader entries to boot partition. Performs state preparation for composefs-setup-root consumption as well. Note that state preparation here is not suitable for consumption by bootc.

Fields

config_opts: OCIConfigOptions
bootdir: PathBuf

boot partition mount point

entry_id: Option<String>

Boot entry identifier to use. By default uses ID provided by the image or kernel version

cmdline: Vec<String>

additional kernel command line