pub(crate) struct OCIConfigFilesystemOptions {
pub(crate) base_config: OCIConfigOptions,
pub(crate) bootable: bool,
}Expand description
Common options for operations using OCI config manifest streams that may transform the image rootfs
Fields
base_config: OCIConfigOptionsbootable: boolWhether bootable transformation should be performed on the image rootfs