pub(crate) enum Command {
Transaction,
Cat {
name: String,
},
GC {
root: Vec<String>,
dry_run: bool,
},
ImportImage {
reference: String,
},
Oci {
cmd: OciCommand,
},
Mount {
name: String,
mountpoint: String,
},
CreateImage {
fs_opts: FsReadOptions,
image_name: Option<String>,
},
ComputeId {
fs_opts: FsReadOptions,
},
CreateDumpfile {
fs_opts: FsReadOptions,
},
ImageObjects {
name: String,
},
}Variants
Transaction
Take a transaction lock on the repository. This prevents garbage collection from occurring.
Cat
Reconstitutes a split stream and writes it to stdout
Fields
GC
Perform garbage collection
Fields
ImportImage
Imports a composefs image (unsafe!)
Oci
Commands for dealing with OCI images and layers
Fields
cmd: OciCommandMount
Mounts a composefs image, possibly enforcing fsverity of the image
Fields
CreateImage
Read rootfs located at a path, add all files to the repo, then create the composefs image of the rootfs, commit it to the repo, and print its image object ID
Fields
fs_opts: FsReadOptionsComputeId
Read rootfs located at a path, add all files to the repo, then compute the composefs image object id of the rootfs. Note that this does not create or commit the composefs image itself.
Fields
fs_opts: FsReadOptionsCreateDumpfile
Read rootfs located at a path, add all files to the repo, then dump full content of the rootfs to a composefs dumpfile and write to stdout.
Fields
fs_opts: FsReadOptionsImageObjects
Lists all object IDs referenced by an image