pub(crate) enum OciCommand {
Show 14 variants
ImportLayer {
digest: String,
name: Option<String>,
},
LsLayer {
name: String,
},
Dump {
config_opts: OCIConfigFilesystemOptions,
},
Pull {
image: String,
name: Option<String>,
},
ListImages {
json: bool,
},
Inspect {
image: String,
manifest: bool,
config: bool,
},
Tag {
manifest_digest: String,
name: String,
},
Untag {
name: String,
},
LayerInspect {
layer: String,
dumpfile: bool,
json: bool,
},
ComputeId {
config_opts: OCIConfigFilesystemOptions,
},
CreateImage {
config_opts: OCIConfigFilesystemOptions,
image_name: Option<String>,
},
Seal {
config_opts: OCIConfigOptions,
},
Mount {
name: String,
mountpoint: String,
},
PrepareBoot {
config_opts: OCIConfigOptions,
bootdir: PathBuf,
entry_id: Option<String>,
cmdline: Vec<String>,
},
}Variants
ImportLayer
Stores a tar layer file as a splitstream in the repository.
LsLayer
Lists the contents of a tar stream
Fields
Dump
Dump full content of the rootfs of a stored OCI image to a composefs dumpfile and write to stdout
Fields
config_opts: OCIConfigFilesystemOptionsPull
Pull an OCI image to be stored in repo then prints the stream and verity digest of its manifest
Fields
ListImages
List all tagged OCI images in the repository
Inspect
Show information about an OCI image
By default, outputs JSON with manifest, config, and referrers. Use –manifest or –config to output just that raw JSON.
Fields
Tag
Tag an image with a new name
Untag
Remove a tag from an image
LayerInspect
Inspect a stored layer
By default, outputs the raw tar stream to stdout. Use –dumpfile for composefs dumpfile format, or –json for metadata.
Fields
ComputeId
Compute the composefs image object id of the rootfs of a stored OCI image
Fields
config_opts: OCIConfigFilesystemOptionsCreateImage
Create the composefs image of the rootfs of a stored OCI image, commit it to the repo, and print its image object ID
Fields
config_opts: OCIConfigFilesystemOptionsSeal
Seal a stored OCI image by creating a cloned manifest with embedded verity digest (a.k.a. composefs image object ID) in the repo, then prints the stream and verity digest of the new sealed manifest
Fields
config_opts: OCIConfigOptionsMount
Mounts a stored and sealed OCI image by looking up its composefs image. Note that the composefs image must be built and committed to the repo first
Fields
PrepareBoot
Create the composefs image of the rootfs of a stored OCI image, perform bootable transformation, commit it to the repo, then configure boot for the image by writing new boot resources and bootloader entries to boot partition. Performs state preparation for composefs-setup-root consumption as well. Note that state preparation here is not suitable for consumption by bootc.